@@ -73,8 +73,8 @@ sub new {
 		"Mark"		=>	$args{Mark},		# takes "mark value"
 		"Exact"		=>	$args{Exact},		# bool - for L
 		"SYN"		=>	$args{SYN},		# bool, accepts !
-		"TOS"		=>	$args{TOS},
-	        "RedirectPort"  =>      $args{RedirectPort}     #redirect port
+		"TOS"		=>	$args{TOS}
+	        "RedirectPort"  =>      $args{RedirectPort}     # redirect port
 		}, $self;
 }
 
@@ -140,11 +140,11 @@ sub set_opts {
 	    
 	# "Jump" rule
 	if (defined($self->{Rule})) {
-	       if (($self->{Rule} eq "REDIRECT" ) and (defined($self->{RedirectPort}))) {
-                       push(@opts, "-j", "$self->{Rule}", "$self->{RedirectPort}");
-               } else {	    
-		       push(@opts, "-j", "$self->{Rule}");	
-		       }
+		if (($self->{Rule} eq "REDIRECT" ) and (defined($self->{RedirectPort}))) {
+			push(@opts, "-j", "$self->{Rule}", "$self->{RedirectPort}");
+		} else {	 
+			push(@opts, "-j", "$self->{Rule}");
+		}	
 	}
 	if (defined($self->{Interface})) {
 		push(@opts, "-i", "$self->{Interface}");
@@ -342,10 +342,6 @@ Destination address, (see SourceMask).
 
 Destination Port, (see SourcePort).
 
-=item B<RedirectPort>
-
-Specifies the (local) port to redirect to if you are using the REDIRECT rule.
-
 =item B<Prot>
 
 Protocol. Can be tcp, udp, icmp, or all. Required for specifying specific port(s).
@@ -530,22 +526,8 @@ To list current rules in "input" chain to stdout (without parsing through /proc/
  $fw = IPChains->new(Verbose => 1);
  $fw->list("input");
 
-To forward all tcp traffic destined to port 80 to port 3000 instead (this is
-useful for transparently forwarding traffic to a cache):
-
-  use IPChains;
-
-  $fw = IPChains->new(Source       => "0.0.0.0/0",
-                      Destination  => "0.0.0.0/0",
-                      DestPort     => "80",
-                      Interface    => "eth0",
-                      Rule         => "REDIRECT",
-                      RedirectPort => "3000"
-                      );
-  $fw->append("input");
-
 To create a rule that would allow all traffic on an internal lan, and deny
-all tcp traffic from external hosts on relevant ports, and log it,you could
+all tcp traffic from external hosts on relevant ports, and log it,you could 
 use something like:
 
  use IPChains;
@@ -565,6 +547,20 @@ use clopts() to clear it's options, then use attribute() to individually
 specify it's next set of options, then append() it again with the new rule.
 See the examples/ subdirectory in the IPChains.pm source for more examples.
 
+To forward all tcp traffic destined to port 80 to port 3000 instead (this is
+useful for transparently forwarding traffic to a cache):
+
+  use IPChains;
+
+  $fw = IPChains->new(Source       => "0.0.0.0/0",
+                      Destination  => "0.0.0.0/0",
+                      DestPort     => "80",
+                      Interface    => "eth0",
+                      Rule         => "REDIRECT",
+                      RedirectPort => "3000"
+                      );
+  $fw->append("input");
+
 =head1 BUGS
 
 Much of this is highly untested. Masquerading timeout setting and negative
@@ -576,7 +572,7 @@ be made.
 
 =head1 AUTHOR
 
-Jessica Quaintance (j@x25.org). Please feel free to email me with
+Jessica Hutchison (j@splatlabs.com). Please feel free to email me with
 feedback, questions, or comments (or indeed patches/additions).
 
 =head1 COPYRIGHT
